@@ -8,7 +8,7 @@ from ..exceptions import YarnNotInstalled
 class BaseYarnCommand(BaseCommand):
     """Base management command with yarn support"""
 
-    requires_system_checks = False
+    requires_system_checks = []
 
     # add fake .options_list for Django>=1.10
     if not hasattr(BaseCommand, 'option_list'):
