@@ -1,6 +1,6 @@
 from ...yarn import yarn_adapter
 from ..base import BaseYarnCommand
-
+from argparse import REMAINDER
 
 class Command(BaseYarnCommand):
     args = 'command'
@@ -8,7 +8,7 @@ class Command(BaseYarnCommand):
         yarn_adapter._node_modules_root)
 
     def add_arguments(self, parser):
-        parser.add_argument('command', nargs='*')
+        parser.add_argument('command', nargs=REMAINDER)
 
     def handle(self, *args, **options):
         super(Command, self).handle(*args, **options)
